﻿# coding: utf-8

"""
 Copyright(c) 2012-2020 E-ICEBLUE Spire.Cloud.Pdf
 
 This program is a free software product. You can redistribute it and/or modify it under the 
 terms of the GNU Affero General Public License (AGPL) version 3 as published by the Free 
 Software Foundation, including without limitation the rights to use, copy, modify, merge, 
 publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to 
 whom the Software is furnished to do so, subject to the following conditions:
  
 The above copyright notice and this permission notice shall be included in all copies or 
 substantial portions of the Software.
 
 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 IMPLIED,INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.IN NO EVENT SHALL THE 
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 LIABILITY,WHETHER IN AN ACTION OF ONTRACT, TORT OR OTHERWISE, ARISING FROM, 
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER EALINGS IN THE 
 SOFTWARE.
"""

from enum import Enum

class TableTestType(Enum):
	TestRequiredItem = 1
	GlobalTextAlignment = 2
	GlobalVerticalAlignment =3
	GlobalCharaSpace=4
	GlobalWordSpace=5
	Font=6
	TextBackGroundColor=7
	TextForeGroundColor=8
	LocalTextAlignment=9
	LocalVerticalAlignment=10
	LocalCharaSpace=11
	LocalWordSpace=12
	CellBorder=13,
	CellBackGroundColor=14
	RowSpan=15
	ColumnSpan=16
	TableHeader=17


from spirecloudpdf.models.point_f import PointF
from spirecloudpdf.models.string_format import StringFormat
from spirecloudpdf.models.tables.table import Table
from spirecloudpdf.models.tables.table_border import TableBorder
from spirecloudpdf.models.tables.table_cell import TableCell
from spirecloudpdf.models.tables.table_column import TableColumn
from spirecloudpdf.models.tables.table_row import TableRow
from spirecloudpdf.models.tables.text_element import TextElement
from spirecloudpdf.models.font import Font
from spirecloudpdf.models.color import Color

class TableTestHelper(object):
	row_Height = 40
	column_Width = 80
	point = PointF(30, 250)
	row_sitem = "China,960,14,Asian,Panda;America,937,3.27,South America,Haliaeetus leucocephalus;".split(";")

	def get_Table(self,testtype):
		
		self.f_Table_Test_Type = testtype
		if   self.f_Table_Test_Type == TableTestType.TestRequiredItem:
			return self.create_RequiredItems_Table()

		elif self.f_Table_Test_Type == TableTestType.GlobalTextAlignment:
			return self.create_GlobalStringFormat_Table()

		elif self.f_Table_Test_Type == TableTestType.GlobalVerticalAlignment:
			return self.create_GlobalStringFormat_Table()
	
		elif self.f_Table_Test_Type == TableTestType.GlobalWordSpace:
			return self.create_GlobalStringFormat_Table()
				
		elif self.f_Table_Test_Type == TableTestType.GlobalCharaSpace:
			return self.create_GlobalStringFormat_Table()
				
		elif self.f_Table_Test_Type == TableTestType.Font:
			return self.create_TableCell_Style()
				
		elif self.f_Table_Test_Type == TableTestType.TextBackGroundColor:
			return self.create_TableCell_Style()
				
		elif self.f_Table_Test_Type == TableTestType.TextForeGroundColor:
			return self.create_TableCell_Style()
				
		elif self.f_Table_Test_Type == TableTestType.CellBorder:
			return self.create_TableCell_Style()
				
		elif self.f_Table_Test_Type == TableTestType.LocalTextAlignment:
			return self.create_TableCell_Style()
				
		elif self.f_Table_Test_Type == TableTestType.LocalVerticalAlignment:
			return self.create_TableCell_Style()
				
		elif self.f_Table_Test_Type == TableTestType.LocalCharaSpace:
			return self.create_TableCell_Style()
				
		elif self.f_Table_Test_Type == TableTestType.LocalWordSpace:
			return self.create_TableCell_Style()
				
		elif self.f_Table_Test_Type == TableTestType.CellBackGroundColor:
			return self.create_TableCell_Style()
				
		elif self.f_Table_Test_Type == TableTestType.RowSpan:
			return self.create_Table_Span()
				
		elif self.f_Table_Test_Type == TableTestType.ColumnSpan:
			return self.create_Table_Span()
				
		elif self.f_Table_Test_Type == TableTestType.TableHeader:
			return self.create_Table_Header()

	def create_RequiredItems_Table(self):
		row_sitem = "China,960,14,Asian,Panda;America,937,3.27,South America,Haliaeetus leucocephalus;".split(";")
		rowlist = []
		row = None
		for	i in range(2):
			cell = None
			celllist = []
			rowstring = row_sitem[i].split(",")

			for j in range(5):
				textElement = TextElement(rowstring[j])
				cell = TableCell(textElement)
            	
				celllist.append(cell)
			
			row = TableRow(self.row_Height, celllist)
        	
			rowlist.append(row)

		columnlist = []
		column = None

		for i in range(5):
			column = TableColumn(self.column_Width + 5 * i)
			columnlist.append(column)

		table = Table(self.point, None, rowlist, columnlist)
		return table

	def create_GlobalStringFormat_Table(self):
		row_sitem = "China,960,14,Asian,Panda;America,937,3.27,South America,Haliaeetus leucocephalus;".split(";")
		rowlist = []
		row = None
		for	i in range(2):
			cell = None
			celllist = []
			rowstring = row_sitem[i].split(",")

			for j in range(5):
				textElement = TextElement(rowstring[j])
				cell = TableCell(textElement)
				celllist.append(cell)
			
			row = TableRow(self.row_Height, celllist)
			rowlist.append(row)
		
		columnlist = []
		column = None

		for i in range(5):
			column = TableColumn(self.column_Width + 5 * i)
			stringformat = StringFormat()

			if self.f_Table_Test_Type == TableTestType.GlobalTextAlignment:
				stringformat.text_alignment = "Center"

			if self.f_Table_Test_Type == TableTestType.GlobalVerticalAlignment:
				stringformat.text_alignment = "Center"
				stringformat.vertical_alignment = "Middle"

			if self.f_Table_Test_Type == TableTestType.GlobalCharaSpace:
				stringformat.text_alignment = "Center"
				stringformat.vertical_alignment = "Middle"
				stringformat.character_spacing = 0.5

			if self.f_Table_Test_Type == TableTestType.GlobalWordSpace:
				stringformat.text_alignment = "Center"
				stringformat.vertical_alignment = "Middle"
				stringformat.character_spacing = 0.5
				stringformat.word_spacing = 5

			column.string_format = stringformat
			columnlist.append(column)


		table =  Table(self.point, None, rowlist, columnlist)
		return table
	
	def create_TableCell_Style(self):
		row_sitem = "China,960,14,Asian,Panda;America,937,3.27,South America,Haliaeetus leucocephalus;".split(";")
		rowlist = []
		row = None

		for i in range(2):
			cell = None 
			celllist = []
			rowstring = row_sitem[i].split(",")

			for j  in range(5):
				textElement = TextElement(rowstring[j])
				font = Font("Standard", "Helvetica", 12, "Regular")
				textForeGroundColor =  Color(10, 255, 0, 0)
				textBackGrounColor =  Color(10, 70, 125, 170)
				stringFormat =  StringFormat()

				if self.f_Table_Test_Type == TableTestType.Font:
					textElement.font = font

				if self.f_Table_Test_Type == TableTestType.TextBackGroundColor:
					textElement.font = font
					textElement._back_ground_color = textBackGrounColor

				if self.f_Table_Test_Type == TableTestType.TextForeGroundColor:
					textElement.font = font
					textElement.back_ground_color = textBackGrounColor
					textElement.fore_ground_color = textForeGroundColor

				if self.f_Table_Test_Type == TableTestType.LocalTextAlignment:
					textElement.font = font
					textElement.back_ground_color = textBackGrounColor
					textElement.fore_ground_color = textForeGroundColor
					stringFormat.text_alignment = "Center"
				
				if self.f_Table_Test_Type == TableTestType.LocalVerticalAlignment:
					textElement.font = font
					textElement.back_ground_color = textBackGrounColor
					textElement.fore_ground_color = textForeGroundColor
					stringFormat.text_alignment = "Center" 
					stringFormat.vertical_alignment = "Middle"

				if self.f_Table_Test_Type == TableTestType.LocalCharaSpace:
					textElement.font = font 
					textElement.back_ground_color = textBackGrounColor
					textElement.fore_ground_color = textForeGroundColor
					stringFormat.text_alignment = "Center"
					stringFormat.vertical_alignment = "Middle"
					stringFormat.character_spacing = 0.5 

				if self.f_Table_Test_Type == TableTestType.LocalWordSpace:
					textElement.font = font
					textElement.back_ground_color = textBackGrounColor
					textElement.fore_ground_color = textForeGroundColor
					stringFormat.text_alignment = "Center"
					stringFormat.vertical_alignment = "Middle"
					stringFormat.character_spacing = 0.5
					stringFormat.word_spacing = 5

				if self.f_Table_Test_Type == TableTestType.CellBorder or self.f_Table_Test_Type == TableTestType.CellBackGroundColor:
					textElement.font = font
					textElement.back_ground_color = textBackGrounColor
					textElement.fore_ground_color = textForeGroundColor
					stringFormat.text_alignment = "Center"
					stringFormat.vertical_alignment = "Middle"
					stringFormat.character_spacing = 0.5
					stringFormat.word_spacing = 5

				textElement.string_format = stringFormat
				cell = TableCell(textElement)

				if self.f_Table_Test_Type == TableTestType.CellBorder:
					tableBorder = TableBorder(Color(15, 25, 25, 100), 1.5)
					cell.table_border = tableBorder

				if self.f_Table_Test_Type == TableTestType.CellBackGroundColor:
					tableBorder = TableBorder(Color(15, 25, 25, 100), 1.5)
					cellBackGroundColor = Color(15, 230, 230, 230)
					cell.table_border = tableBorder
					cell.back_ground_color = cellBackGroundColor

				celllist.append(cell)
			
			row = TableRow(self.row_Height, celllist)
			rowlist.append(row)

		columnlist = []
		column = None

		for i in range(5):
			column = TableColumn(self.column_Width + 5 * i)
			columnlist.append(column)

		table = Table(self.point, None, rowlist, columnlist)
		return table

	def create_Table_Span(self):
		
		row_sitem = "China,960,14,Asian,Panda;Japanese,37.8,1.27,Asian,Crested Ibis;".split(";")
		rowlist = []
		row = None

		for i in range(2):
			cell = None
			celllist = []
			rowstring = row_sitem[i].split(",")

			for j in range(5):
				textElement = TextElement(rowstring[j])
				font = Font("Standard", "Helvetica", 12, "Regular")
				textForeGroundColor = Color(10, 255, 0, 0)
				textBackGrounColor = Color(10, 70, 125, 170)
				stringFormat = StringFormat()

				textElement.font = font
				textElement.back_ground_color = textBackGrounColor
				textElement.fore_ground_color = textForeGroundColor
				stringFormat.text_alignment = "Center"
				stringFormat.vertical_alignment = "Middle"
				stringFormat.character_spacing = 0.5
				stringFormat.word_spacing = 5
				textElement.string_format = stringFormat

				cell = TableCell(textElement)
				tableBorder = TableBorder(Color(15, 25, 25, 100), 1.5)
				cellBackGroundColor = Color(15, 230, 230, 230)
				cell.table_border = tableBorder
				cell.back_ground_color = cellBackGroundColor

				if self.f_Table_Test_Type == TableTestType.RowSpan and i == 0 and j == 3:
					cell.row_span = 2

				if self.f_Table_Test_Type == TableTestType.ColumnSpan and i == 0 and j == 1:
					cell.column_span = 2
					cell.text_element.text = "vast territory and abundant resources"

				celllist.append(cell)

			row = TableRow(self.row_Height, celllist)
			rowlist.append(row)
			
		columnlist = []
		column = None
		for i  in range(5):
			column = TableColumn(self.column_Width + 5 * i)
			columnlist.append(column)

		table = Table(self.point, None, rowlist, columnlist)
		return table

	def create_Table_Header(self):

		headerItems = "Country,Area,Population,geography,NationalTreasure".split(",")
		row_sitem = "China,960,14,Asian,Panda;Japanese,37.8,1.27,Asian,Crested Ibis;".split(";")
		header = None
		headerCell = None
		headerCelllist = []

		for i in range(5):
			textElement = TextElement(headerItems[i])
			font = Font("Standard", "Helvetica", 12, "Regular")
			textForeGroundColor = Color(10, 255, 0, 0)
			textBackGrounColor = Color(10, 70, 125, 170)
			stringFormat = StringFormat()

			textElement.font = font
			textElement.back_ground_color = textBackGrounColor
			textElement.fore_ground_color = textForeGroundColor
			stringFormat.text_alignment = "Center"
			stringFormat.vertical_alignment = "Middle"
			stringFormat.character_spacing = 0.5
			stringFormat.word_spacing = 5
			textElement.string_format = stringFormat	

			headerCell = TableCell(textElement)
			tableBorder = TableBorder(Color(15, 25, 25, 100), 1.5)
			cellBackGroundColor = Color(15, 230, 230, 230)
			headerCell.table_border = tableBorder
			headerCell.back_ground_color = cellBackGroundColor
			headerCelllist.append(headerCell)

		header = TableRow(self.row_Height, headerCelllist);	
		rowlist = []
		row = None

		for i in range(2):
			cell = None
			celllist = []
			rowstring = row_sitem[i].split(",")

			for j in range(5):
				textElement = TextElement(rowstring[j])
				font = Font("Standard", "Helvetica", 12, "Regular")
				textForeGroundColor = Color(10, 255, 0, 0)
				textBackGrounColor = Color(10, 70, 125, 170)
				stringFormat = StringFormat()

				textElement.font = font
				textElement.back_ground_color = textBackGrounColor
				textElement.fore_ground_color = textForeGroundColor
				stringFormat.text_alignment = "Center"
				stringFormat.vertical_alignment = "Middle"
				stringFormat.character_spacing = 0.5
				stringFormat.word_spacing = 5
				textElement.string_format = stringFormat

				cell = TableCell(textElement)

				tableBorder = TableBorder(Color(15, 25, 25, 100), 1.5)
				cellBackGroundColor = Color(15, 230, 230, 230)
				cell.table_border = tableBorder
				cell.back_ground_color = cellBackGroundColor

				if i == 0 and j == 3:
					cell.row_span = 2
				
				if i == 0 and j == 1:
					cell.column_span = 2
					cell.text_element.text = "vast territory and abundant resources"
					
				celllist.append(cell)

			row = TableRow(self.row_Height, celllist)
			rowlist.append(row)

		columnlist = []
		column = None

		for i in range(5):
			column = TableColumn(self.column_Width + 8 * i)
			columnlist.append(column)

		table = Table(self.point, header, rowlist, columnlist)
		return table

                        
                        
                    









                       
					   
                        



						
                        
                    
                        


		







