# coding: utf-8

"""
 Copyright(c) 2012-2020 E-ICEBLUE Spire.Cloud.Pdf
 
 This program is a free software product. You can redistribute it and/or modify it under the 
 terms of the GNU Affero General Public License (AGPL) version 3 as published by the Free 
 Software Foundation, including without limitation the rights to use, copy, modify, merge, 
 publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to 
 whom the Software is furnished to do so, subject to the following conditions:
  
 The above copyright notice and this permission notice shall be included in all copies or 
 substantial portions of the Software.
 
 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 IMPLIED,INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.IN NO EVENT SHALL THE 
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 LIABILITY,WHETHER IN AN ACTION OF ONTRACT, TORT OR OTHERWISE, ARISING FROM, 
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER EALINGS IN THE 
 SOFTWARE.
"""

from enum import Enum


class ListBoxFieldTestType(Enum):
    Required = 1
    MappingName = 2
    ToolTip = 3
    Value = 4
    SelectedIndexs = 5

from spirecloudpdf.models.acroform.list_box_field import ListBoxField
from spirecloudpdf.models.rectangle_f import RectangleF

class ListBoxHelper(object):

    def get_listbox_field(self,testtype):
        if testtype == ListBoxFieldTestType.Required:
            return self.SimpleListBoxField()

        elif testtype == ListBoxFieldTestType.MappingName:
            return self.MappingNameListBoxField()

        elif testtype == ListBoxFieldTestType.SelectedIndexs:
            return self.SelectedIndexsListBoxField()

        elif testtype == ListBoxFieldTestType.ToolTip:
            return self.ToolTipListBoxField()

        elif testtype == ListBoxFieldTestType.Value:
            return self.ValuesListBoxField()

    def SimpleListBoxField(self):
        listBoxFlags = []
        listBoxFlags.append("MultiSelect")
        listBoxFlags.append("CommitOnSelChange")
        bounds = RectangleF(100, 250, 150, 60)
        return ListBoxField(listBoxFlags, bounds, "email_format", 1)

    def MappingNameListBoxField(self):
        listBoxFlags = []
        listBoxFlags.append("MultiSelect")
        listBoxFlags.append("CommitOnSelChange")
        bounds = RectangleF(100, 250, 150, 60)
        listbox_field = ListBoxField(listBoxFlags, bounds, "email_format", 1)
        listbox_field.mapping_name = "ListBoxMapingName"
        return listbox_field

    def ToolTipListBoxField(self):
        listBoxFlags = []
        listBoxFlags.append("MultiSelect")
        listBoxFlags.append("CommitOnSelChange")
        bounds = RectangleF(100, 250, 150, 60)
        listbox_field = ListBoxField(listBoxFlags, bounds, "email_format", 1)
        listbox_field.mapping_name = "ListBoxMapingName"
        listbox_field.tool_tip = "ListBoxToolTip"
        return listbox_field

    def ValuesListBoxField(self):
        listBoxFlags = []
        listBoxFlags.append("MultiSelect")
        listBoxFlags.append("CommitOnSelChange")
        bounds = RectangleF(100, 250, 150, 60)
        listbox_field = ListBoxField(listBoxFlags, bounds, "email_format", 1)
        listbox_field.mapping_name = "ListBoxMapingName"
        listbox_field.tool_tip = "ListBoxToolTip"
        values = [ "PDF", "XLS", "PPT", "DOC", "DOCX" ]
        listbox_field.values = values
        return listbox_field

    def SelectedIndexsListBoxField(self):
        listBoxFlags = []
        listBoxFlags.append("MultiSelect")
        listBoxFlags.append("CommitOnSelChange")
        bounds = RectangleF(100, 250, 150, 60)
        listbox_field = ListBoxField(listBoxFlags, bounds, "email_format", 1)
        listbox_field.mapping_name = "ListBoxMapingName"
        listbox_field.tool_tip = "ListBoxToolTip"
        values = [ "PDF", "XLS", "PPT", "DOC", "DOCX" ]
        listbox_field.values = values
        listbox_field.selected_indexs = [1,2]
        return listbox_field






    


