# coding: utf-8

"""
 Copyright(c) 2012-2020 E-ICEBLUE Spire.Cloud.Pdf
 
 This program is a free software product. You can redistribute it and/or modify it under the 
 terms of the GNU Affero General Public License (AGPL) version 3 as published by the Free 
 Software Foundation, including without limitation the rights to use, copy, modify, merge, 
 publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to 
 whom the Software is furnished to do so, subject to the following conditions:
  
 The above copyright notice and this permission notice shall be included in all copies or 
 substantial portions of the Software.
 
 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 IMPLIED,INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.IN NO EVENT SHALL THE 
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 LIABILITY,WHETHER IN AN ACTION OF ONTRACT, TORT OR OTHERWISE, ARISING FROM, 
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER EALINGS IN THE 
 SOFTWARE.
"""

from enum import Enum

class TextBoxFieldTestType(Enum):
    Required = 1
    MappingName = 2
    ToolTip = 3
    Value = 4
    ForeColor = 5
    DefaultValue = 6
    MaxLength = 7
    HighlightMode = 8
    TextAlignment = 9
from spirecloudpdf.models.acroform.text_box_field import TextBoxField
from spirecloudpdf.models.rectangle_f import RectangleF
from spirecloudpdf.models.color import Color


class TextBoxHelper(object):

    def get_textbox_field(self,testtype):

        if   testtype == TextBoxFieldTestType.Required:
            return self.SimpleTextBoxField()

        elif testtype == TextBoxFieldTestType.MappingName:
            return self.MappingNameTextBoxField()

        elif testtype == TextBoxFieldTestType.ToolTip:
            return self.ToolTipTextBoxField()
        
        elif testtype == TextBoxFieldTestType.Value:
            return self.ValuesTextBoxField()

        elif testtype == TextBoxFieldTestType.ForeColor:
            return self.ForeColorTextBoxField()

        elif testtype == TextBoxFieldTestType.DefaultValue:
            return self.DefaultValueTextBoxField()

        elif testtype == TextBoxFieldTestType.MaxLength:
            return self.MaxLengthTextBoxField()

        elif testtype == TextBoxFieldTestType.HighlightMode:
            return self.HighlightModeTextBoxField()

        elif testtype == TextBoxFieldTestType.TextAlignment:
            return self.TextAlignmentTextBoxField()

    def SimpleTextBoxField(self):
        textBoxFlags = []
        textBoxFlags.append("NoExport")
        textBoxFlags.append("Multiline")
        textBoxFlags.append("DoNotSpellCheck")
        return TextBoxField(textBoxFlags, "fax", 1, RectangleF(300, 500, 150, 80))

    def MappingNameTextBoxField(self):
        textBoxFlags = []
        textBoxFlags.append("NoExport")
        textBoxFlags.append("Multiline")
        textBoxFlags.append("DoNotSpellCheck")
        textBox = TextBoxField(textBoxFlags, "fax", 1, RectangleF(300, 500, 150, 80))
        textBox.mapping_name = "TextBoxMapingName"
        return textBox 

    def ToolTipTextBoxField(self):
        textBoxFlags = []
        textBoxFlags.append("NoExport")
        textBoxFlags.append("Multiline")
        textBoxFlags.append("DoNotSpellCheck")
        textBox = TextBoxField(textBoxFlags, "fax", 1, RectangleF(300, 500, 150, 80))
        textBox.mapping_name = "TextBoxMapingName"
        textBox.tool_tip = "TextBoxToolTip"
        return textBox

    def ValuesTextBoxField(self) :
        textBoxFlags = []
        textBoxFlags.append("NoExport")
        textBoxFlags.append("Multiline")
        textBoxFlags.append("DoNotSpellCheck")
        textBox = TextBoxField(textBoxFlags, "fax", 1, RectangleF(300, 500, 150, 80))
        textBox.mapping_name = "TextBoxMapingName"
        textBox.tool_tip = "TextBoxToolTip"
        textBox.value = "textBoxNewLineText"
        return textBox

    def TextAlignmentTextBoxField(self):
        textBoxFlags = []
        textBoxFlags.append("NoExport")
        textBoxFlags.append("Multiline")
        textBoxFlags.append("DoNotSpellCheck")
        textBox = TextBoxField(textBoxFlags, "fax", 1, RectangleF(300, 500, 150, 80))
        textBox.mapping_name = "TextBoxMapingName"
        textBox.tool_tip = "TextBoxToolTip"
        textBox.value = "textBoxNewLineText"
        textBox.text_alignment = "Center"
        return textBox

    def HighlightModeTextBoxField(self):
        textBoxFlags = []
        textBoxFlags.append("NoExport")
        textBoxFlags.append("Multiline")
        textBoxFlags.append("DoNotSpellCheck")
        textBox = TextBoxField(textBoxFlags, "fax", 1, RectangleF(300, 500, 150, 80))
        textBox.mapping_name = "TextBoxMapingName"
        textBox.tool_tip = "TextBoxToolTip"
        textBox.value = "textBoxNewLineText"
        textBox.text_alignment = "Center"
        textBox.highlight_mode = "NoHighlighting"
        return textBox

    def MaxLengthTextBoxField(self):
        textBoxFlags = []
        textBoxFlags.append("NoExport")
        textBoxFlags.append("Multiline")
        textBoxFlags.append("DoNotSpellCheck")
        textBox = TextBoxField(textBoxFlags, "fax", 1, RectangleF(300, 500, 150, 80))
        textBox.mapping_name = "TextBoxMapingName"
        textBox.tool_tip = "TextBoxToolTip"
        textBox.value = "textBoxNewLineText"
        textBox.text_alignment = "Center"
        textBox.highlight_mode = "NoHighlighting"
        textBox.max_length = 250
        return textBox

    def DefaultValueTextBoxField(self):
        textBoxFlags = []
        textBoxFlags.append("NoExport")
        textBoxFlags.append("Multiline")
        textBoxFlags.append("DoNotSpellCheck")
        textBox = TextBoxField(textBoxFlags, "fax", 1, RectangleF(300, 500, 150, 80))
        textBox.mapping_name = "TextBoxMapingName"
        textBox.tool_tip = "TextBoxToolTip"
        textBox.value = "textBoxNewLineText"
        textBox.text_alignment = "Center"
        textBox.highlight_mode = "NoHighlighting"
        textBox.max_length = 250
        textBox.default_value = "DefaultValue"
        return textBox

    def ForeColorTextBoxField(self):
        textBoxFlags = []
        textBoxFlags.append("NoExport")
        textBoxFlags.append("Multiline")
        textBoxFlags.append("DoNotSpellCheck")
        textBox = TextBoxField(textBoxFlags, "fax", 1, RectangleF(300, 500, 150, 80))
        textBox.mapping_name = "TextBoxMapingName"
        textBox.tool_tip = "TextBoxToolTip"
        textBox.value = "textBoxNewLineTexttextBoxNewLineTexttextBoxNewLineTexttextBoxNewLineTexttextBoxNewLineTexttextBoxNewLineTexttextBoxNewLineText"
        textBox.text_alignment = "Center"
        textBox.highlight_mode = "NoHighlighting"
        textBox.max_length = 250
        textBox.default_value = "DefaultValue"
        textBox.fore_color = Color (255,255,182,193)
        return textBox











            